@@ -15,7 +15,7 @@ has 'password';
 has 'proxy';
 has 'ua' => sub { Mojo::UserAgent->new; };
 
-our $VERSION = '1.2.12.1';
+our $VERSION = '1.2.13.0';
 
 
 sub _execute {
@@ -543,6 +543,36 @@ sub set_text {
 #################### subroutine header end ####################
 
 
+sub append_text {
+    my $c      = shift;
+    my $pad_id = shift;
+    my $text   = shift;
+
+    unless (defined($text)) {
+        carp 'Please provide 2 arguments : a pad id and a text';
+        return undef;
+    }
+
+    my $args = {
+        padID => $pad_id,
+        text  => $text
+    };
+
+    return $c->_execute({
+        api     => '1.2.13',
+        method  => 'appendText',
+        boolean => 1,
+        args    => $args
+    });
+}
+
+
+#################### subroutine header begin ####################
+
+
+#################### subroutine header end ####################
+
+
 sub get_html {
     my $c      = shift;
     my $pad_id = shift;
@@ -1474,7 +1504,7 @@ Etherpad - interact with Etherpad API
 
 =head1 VERSION
 
-version 1.2.12.1
+version 1.2.13.0
 
 =head1 SYNOPSIS
 
@@ -1496,7 +1526,7 @@ version 1.2.12.1
 
 Client module for the Etherpad HTTP API.
 
-The Etherpad API currently supported is the 1.2.12 (Etherpad version: 1.5.6)
+The Etherpad API currently supported is the 1.2.13 (Etherpad version: 1.6.0)
 
 This module aims to replace L<Etherpad::API>
 
@@ -1557,7 +1587,7 @@ Etherpad inherits all methods from Mojo::Base and implements the following new o
 
 Pads can belong to a group. The padID of grouppads is starting with a groupID like g.asdfasdfasdfasdf$test
 
-See L<http://etherpad.org/doc/v1.5.6/#index_groups>
+See L<http://etherpad.org/doc/v1.6.0/#index_groups>
 
 =head3 create_group
 
@@ -1565,7 +1595,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_groups>
  Purpose   : Creates a new group
  Returns   : The new group ID
  Argument  : None
- See       : http://etherpad.org/doc/v1.5.6/#index_creategroup
+ See       : http://etherpad.org/doc/v1.6.0/#index_creategroup
 
 =head3 create_group_if_not_exists_for
 
@@ -1573,7 +1603,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_groups>
  Purpose   : This functions helps you to map your application group ids to epl group ids
  Returns   : The epl group id
  Argument  : Your application group id
- See       : http://etherpad.org/doc/v1.5.6/#index_creategroupifnotexistsfor_groupmapper
+ See       : http://etherpad.org/doc/v1.6.0/#index_creategroupifnotexistsfor_groupmapper
 
 =head3 delete_group
 
@@ -1581,7 +1611,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_groups>
  Purpose   : Deletes a group
  Returns   : 1 if it succeeds
  Argument  : The id of the group you want to delete
- See       : http://etherpad.org/doc/v1.5.6/#index_deletegroup_groupid
+ See       : http://etherpad.org/doc/v1.6.0/#index_deletegroup_groupid
 
 =head3 list_pads
 
@@ -1589,7 +1619,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_groups>
  Purpose   : Returns all pads of this group
  Returns   : An array or an array reference (depending on the context) which contains the pad ids
  Argument  : The id of the group from which you want the pads
- See       : http://etherpad.org/doc/v1.5.6/#index_listpads_groupid
+ See       : http://etherpad.org/doc/v1.6.0/#index_listpads_groupid
 
 =head3 create_group_pad
 
@@ -1597,7 +1627,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_groups>
  Purpose   : Creates a new pad in this group
  Returns   : 1 if it succeeds
  Argument  : The group id, the pad name, optionally takes the pad's initial text
- See       : http://etherpad.org/doc/v1.5.6/#index_creategrouppad_groupid_padname_text
+ See       : http://etherpad.org/doc/v1.6.0/#index_creategrouppad_groupid_padname_text
 
 =head3 list_all_groups
 
@@ -1605,13 +1635,13 @@ See L<http://etherpad.org/doc/v1.5.6/#index_groups>
  Purpose   : Lists all existing groups
  Returns   : An array or an array reference (depending on the context) which contains the groups ids
  Argument  : None
- See       : http://etherpad.org/doc/v1.5.6/#index_listallgroups
+ See       : http://etherpad.org/doc/v1.6.0/#index_listallgroups
 
 =head2 Author
 
 These authors are bound to the attributes the users choose (color and name).
 
-See L<http://etherpad.org/doc/v1.5.6/#index_author>
+See L<http://etherpad.org/doc/v1.6.0/#index_author>
 
 =head3 create_author
 
@@ -1619,7 +1649,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_author>
  Purpose   : Creates a new author
  Returns   : The new author ID
  Argument  : Optionally takes a string as argument : the new author's name
- See       : http://etherpad.org/doc/v1.5.6/#index_createauthor_name
+ See       : http://etherpad.org/doc/v1.6.0/#index_createauthor_name
 
 =head3 create_author_if_not_exists_for
 
@@ -1627,7 +1657,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_author>
  Purpose   : This functions helps you to map your application author ids to epl author ids
  Returns   : The epl author ID
  Argument  : Your application author ID (mandatory) and optionally the epl author name
- See       : http://etherpad.org/doc/v1.5.6/#index_createauthorifnotexistsfor_authormapper_name
+ See       : http://etherpad.org/doc/v1.6.0/#index_createauthorifnotexistsfor_authormapper_name
 
 =head3 list_pads_of_author
 
@@ -1635,7 +1665,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_author>
  Purpose   : Returns an array of all pads this author contributed to
  Returns   : An array or an array reference depending on the context, containing the pads names
  Argument  : An epl author ID
- See       : http://etherpad.org/doc/v1.5.6/#index_listpadsofauthor_authorid
+ See       : http://etherpad.org/doc/v1.6.0/#index_listpadsofauthor_authorid
 
 =head3 get_author_name
 
@@ -1643,13 +1673,13 @@ See L<http://etherpad.org/doc/v1.5.6/#index_author>
  Purpose   : Returns the Author Name of the author
  Returns   : The author name
  Argument  : The epl author ID
- See       : http://etherpad.org/doc/v1.5.6/#index_getauthorname_authorid
+ See       : http://etherpad.org/doc/v1.6.0/#index_getauthorname_authorid
 
 =head2 Session
 
 Sessions can be created between a group and an author. This allows an author to access more than one group. The sessionID will be set as a cookie to the client and is valid until a certain date. The session cookie can also contain multiple comma-seperated sessionIDs, allowing a user to edit pads in different groups at the same time. Only users with a valid session for this group, can access group pads. You can create a session after you authenticated the user at your web application, to give them access to the pads. You should save the sessionID of this session and delete it after the user logged out.
 
-See L<http://etherpad.org/doc/v1.5.6/#index_session>
+See L<http://etherpad.org/doc/v1.6.0/#index_session>
 
 =head3 create_session
 
@@ -1657,7 +1687,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_session>
  Purpose   : Creates a new session. validUntil is an unix timestamp in seconds
  Returns   : The epl session ID
  Argument  : An epl group ID, an epl author ID and an valid unix timestamp (the session validity end date)
- See       : http://etherpad.org/doc/v1.5.6/#index_createsession_groupid_authorid_validuntil
+ See       : http://etherpad.org/doc/v1.6.0/#index_createsession_groupid_authorid_validuntil
 
 =head3 delete_session
 
@@ -1665,7 +1695,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_session>
  Purpose   : Deletes a session
  Returns   : 1 if it succeeds
  Argument  : An epl session ID
- See       : http://etherpad.org/doc/v1.5.6/#index_deletesession_sessionid
+ See       : http://etherpad.org/doc/v1.6.0/#index_deletesession_sessionid
 
 =head3 get_session_info
 
@@ -1673,7 +1703,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_session>
  Purpose   : Returns informations about a session
  Returns   : A hash reference, containing 3 keys : authorID, groupID and validUntil
  Argument  : An epl session ID
- See       : http://etherpad.org/doc/v1.5.6/#index_getsessioninfo_sessionid
+ See       : http://etherpad.org/doc/v1.6.0/#index_getsessioninfo_sessionid
 
 =head3 list_sessions_of_group
 
@@ -1681,7 +1711,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_session>
  Purpose   : Returns all sessions of a group
  Returns   : Returns a hash reference, which keys are sessions ID and values are sessions infos (see get_session_info)
  Argument  : An epl group ID
- See       : http://etherpad.org/doc/v1.5.6/#index_listsessionsofgroup_groupid
+ See       : http://etherpad.org/doc/v1.6.0/#index_listsessionsofgroup_groupid
 
 =head3 list_sessions_of_author
 
@@ -1689,13 +1719,13 @@ See L<http://etherpad.org/doc/v1.5.6/#index_session>
  Purpose   : Returns all sessions of an author
  Returns   : Returns a hash reference, which keys are sessions ID and values are sessions infos (see get_session_info)
  Argument  : An epl group ID
- See       : http://etherpad.org/doc/v1.5.6/#index_listsessionsofauthor_authorid
+ See       : http://etherpad.org/doc/v1.6.0/#index_listsessionsofauthor_authorid
 
 =head2 Pad Content
 
 Pad content can be updated and retrieved through the API.
 
-See L<http://etherpad.org/doc/v1.5.6/#index_pad_content>
+See L<http://etherpad.org/doc/v1.6.0/#index_pad_content>
 
 =head3 get_text
 
@@ -1703,7 +1733,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad_content>
  Purpose   : Returns the text of a pad
  Returns   : A string, containing the text of the pad
  Argument  : Takes a pad ID (mandatory) and optionally a revision number
- See       : http://etherpad.org/doc/v1.5.6/#index_gettext_padid_rev
+ See       : http://etherpad.org/doc/v1.6.0/#index_gettext_padid_rev
 
 =head3 set_text
 
@@ -1711,7 +1741,15 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad_content>
  Purpose   : Sets the text of a pad
  Returns   : 1 if it succeeds
  Argument  : Takes a pad ID and the text you want to set (both mandatory)
- See       : http://etherpad.org/doc/v1.5.6/#index_settext_padid_text
+ See       : http://etherpad.org/doc/v1.6.0/#index_settext_padid_text
+
+=head3 append_text
+
+ Usage     : $ec->append_text('padID', 'text')
+ Purpose   : Appends text to a pad
+ Returns   : 1 if it succeeds
+ Argument  : Takes a pad ID and the text you want to append (both mandatory)
+ See       : http://etherpad.org/doc/v1.6.0/#index_appendtext_padid_text
 
 =head3 get_html
 
@@ -1719,7 +1757,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad_content>
  Purpose   : Returns the text of a pad formatted as html
  Returns   : A string, containing the text of the pad formatted as html
  Argument  : Takes a pad ID (mandatory) and optionally a revision number
- See       : http://etherpad.org/doc/v1.5.6/#index_gethtml_padid_rev
+ See       : http://etherpad.org/doc/v1.6.0/#index_gethtml_padid_rev
 
 =head3 set_html
 
@@ -1727,7 +1765,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad_content>
  Purpose   : Sets the text of a pad based on HTML, HTML must be well formed.
  Returns   : 1 if it succeeds
  Argument  : Takes a pad ID and the HTML code you want to set (both mandatory)
- See       : http://etherpad.org/doc/v1.5.6/#index_sethtml_padid_html
+ See       : http://etherpad.org/doc/v1.6.0/#index_sethtml_padid_html
 
 =head3 get_attribute_pool
 
@@ -1738,7 +1776,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad_content>
              * attribToNum, containing a hash reference, which keys are string and contents are integers
              * nextNum, which content is an integer
  Argument  : Takes a pad ID (mandatory)
- See       : http://etherpad.org/doc/v1.5.6/#index_getattributepool_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_getattributepool_padid
 
 =head3 get_revision_changeset
 
@@ -1746,7 +1784,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad_content>
  Purpose   : Get the changeset at a given revision, or last revision if 'rev' is not defined
  Returns   : A string, representing an etherpad changeset
  Argument  : Takes a pad ID (mandatory) and optionally a revision number
- See       : http://etherpad.org/doc/v1.5.6/#index_getrevisionchangeset_padid_rev
+ See       : http://etherpad.org/doc/v1.6.0/#index_getrevisionchangeset_padid_rev
 
 =head3 create_diff_html
 
@@ -1756,11 +1794,11 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad_content>
              * html, which content is a string representing the diff between the two revisions
              * authors, which content is an array reference of authors
  Argument  : Takes a pad ID, a revision number to start and a revision number to end. All arguments are mandatory
- See       : http://etherpad.org/doc/v1.5.6/#index_creatediffhtml_padid_startrev_endrev
+ See       : http://etherpad.org/doc/v1.6.0/#index_creatediffhtml_padid_startrev_endrev
 
 =head2 Chat
 
-See L<http://etherpad.org/doc/v1.5.6/#index_chat>
+See L<http://etherpad.org/doc/v1.6.0/#index_chat>
 
 =head3 get_chat_history
 
@@ -1776,7 +1814,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_chat>
  Argument  : Takes a pad ID (mandatory) and optionally the start and the end numbers of the messages you want.
              The start number can't be higher than or equal to the current chatHead. The first chat message is number 0.
              If you specify a start but not an end, all messages will be returned.
- See       : http://etherpad.org/doc/v1.5.6/#index_getchathistory_padid_start_end
+ See       : http://etherpad.org/doc/v1.6.0/#index_getchathistory_padid_start_end
 
 =head3 get_chat_head
 
@@ -1784,7 +1822,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_chat>
  Purpose   : Returns the chatHead (last number of the last chat-message) of the pad
  Returns   : The last chat-message number. -1 if there is no chat message
  Argument  : A pad ID
- See       : http://etherpad.org/doc/v1.5.6/#index_getchathead_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_getchathead_padid
 
 =head3 append_chat_message
 
@@ -1798,7 +1836,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_chat>
 
 Group pads are normal pads, but with the name schema GROUPID$PADNAME. A security manager controls access of them and its forbidden for normal pads to include a $ in the name.
 
-See L<http://etherpad.org/doc/v1.5.6/#index_pad>
+See L<http://etherpad.org/doc/v1.6.0/#index_pad>
 
 =head3 create_pad
 
@@ -1806,7 +1844,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Creates a new (non-group) pad. Note that if you need to create a group Pad, you should call create_group_pad.
  Returns   : 1 if it succeeds
  Argument  : Takes a pad ID (mandatory) and optionally a text to fill the pad
- See       : http://etherpad.org/doc/v1.5.6/#index_createpad_padid_text
+ See       : http://etherpad.org/doc/v1.6.0/#index_createpad_padid_text
 
 =head3 get_revisions_count
 
@@ -1814,7 +1852,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Returns the number of revisions of this pad
  Returns   : The number of revisions
  Argument  : A pad ID
- See       : http://etherpad.org/doc/v1.5.6/#index_getrevisionscount_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_getrevisionscount_padid
 
 =head3 get_saved_revisions_count
 
@@ -1822,7 +1860,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Returns the number of saved revisions of this pad
  Returns   : The number of saved revisions
  Argument  : A pad ID
- See       : http://etherpad.org/doc/v1.5.6/#index_getsavedrevisionscount_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_getsavedrevisionscount_padid
 
 =head3 list_saved_revisions
 
@@ -1830,7 +1868,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Returns the list of saved revisions of this pad
  Returns   : An array or an array reference, depending of the context, containing the saved revisions numbers
  Argument  : A pad ID
- See       : http://etherpad.org/doc/v1.5.6/#index_listsavedrevisions_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_listsavedrevisions_padid
 
 =head3 save_revision
 
@@ -1838,7 +1876,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Saves a revision
  Returns   : 1 if it succeeds
  Argument  : Takes a pad ID (mandatory) and optionally a revision number
- See       : http://etherpad.org/doc/v1.5.6/#index_saverevision_padid_rev
+ See       : http://etherpad.org/doc/v1.6.0/#index_saverevision_padid_rev
 
 =head3 get_users_count
 
@@ -1850,7 +1888,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Returns the number of user that are currently editing this pad
  Returns   : The number of users
  Argument  : A pad ID
- See       : http://etherpad.org/doc/v1.5.6/#index_paduserscount_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_paduserscount_padid
 
 =head3 pad_users
 
@@ -1858,7 +1896,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Returns the list of users that are currently editing this pad
  Returns   : An array or an array reference, depending of the context, containing hash references with 3 keys : colorId, name and timestamp
  Argument  : A pad ID
- See       : http://etherpad.org/doc/v1.5.6/#index_padusers_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_padusers_padid
 
 =head3 delete_pad
 
@@ -1866,7 +1904,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Deletes a pad
  Returns   : 1 if it succeeds
  Argument  : A pad ID
- See       : http://etherpad.org/doc/v1.5.6/#index_deletepad_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_deletepad_padid
 
 =head3 copy_pad
 
@@ -1876,7 +1914,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Argument  : A source pad ID
              A destination pad ID
              A force flag : a value which is true or false, in perl interpretation (for example; 0 and '' are false, 1, 2 and 'foo' are true)
- See       : http://etherpad.org/doc/v1.5.6/#index_copypad_sourceid_destinationid_force_false
+ See       : http://etherpad.org/doc/v1.6.0/#index_copypad_sourceid_destinationid_force_false
 
 =head3 move_pad
 
@@ -1886,7 +1924,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Argument  : A source pad ID
              A destination pad ID
              A force flag : a value which is true or false, in perl interpretation (for example; 0 and '' are false, 1, 2 and 'foo' are true)
- See       : http://etherpad.org/doc/v1.5.6/#index_movepad_sourceid_destinationid_force_false
+ See       : http://etherpad.org/doc/v1.6.0/#index_movepad_sourceid_destinationid_force_false
 
 =head3 get_read_only_id
 
@@ -1894,7 +1932,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Returns the read only link of a pad
  Returns   : A string
  Argument  : A pad ID
- See       : http://etherpad.org/doc/v1.5.6/#index_getreadonlyid_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_getreadonlyid_padid
 
 =head3 get_pad_id
 
@@ -1902,7 +1940,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Returns the id of a pad which is assigned to the readOnlyID
  Returns   : A string
  Argument  : A read only ID
- See       : http://etherpad.org/doc/v1.5.6/#index_getpadid_readonlyid
+ See       : http://etherpad.org/doc/v1.6.0/#index_getpadid_readonlyid
 
 =head3 set_public_status
 
@@ -1910,7 +1948,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Sets a boolean for the public status of a pad
  Returns   : 1 if it succeeds
  Argument  : A pad ID and the public status you want to set : 1 or 0
- See       : http://etherpad.org/doc/v1.5.6/#index_setpublicstatus_padid_publicstatus
+ See       : http://etherpad.org/doc/v1.6.0/#index_setpublicstatus_padid_publicstatus
 
 =head3 get_public_status
 
@@ -1918,7 +1956,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Return true of false
  Returns   : 1 or 0
  Argument  : A pad ID
- See       : http://etherpad.org/doc/v1.5.6/#index_getpublicstatus_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_getpublicstatus_padid
 
 =head3 set_password
 
@@ -1926,7 +1964,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Returns ok or a error message
  Returns   : 1 if it succeeds
  Argument  : A pad ID and a password
- See       : http://etherpad.org/doc/v1.5.6/#index_setpassword_padid_password
+ See       : http://etherpad.org/doc/v1.6.0/#index_setpassword_padid_password
 
 =head3 is_password_protected
 
@@ -1934,7 +1972,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Returns true or false
  Returns   : 1 or 0
  Argument  : A pad ID
- See       : http://etherpad.org/doc/v1.5.6/#index_ispasswordprotected_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_ispasswordprotected_padid
 
 =head3 list_authors_of_pad
 
@@ -1942,7 +1980,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Returns an array of authors who contributed to this pad
  Returns   : An array or an array reference depending on the context, containing the epl authors IDs
  Argument  : A pad ID
- See       : http://etherpad.org/doc/v1.5.6/#index_listauthorsofpad_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_listauthorsofpad_padid
 
 =head3 list_names_of_authors_of_pad
 
@@ -1958,7 +1996,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Returns the timestamp of the last revision of the pad
  Returns   : A unix timestamp
  Argument  : A pad ID
- See       : http://etherpad.org/doc/v1.5.6/#index_getlastedited_padid
+ See       : http://etherpad.org/doc/v1.6.0/#index_getlastedited_padid
 
 =head3 send_clients_message
 
@@ -1966,7 +2004,7 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Sends a custom message of type msg to the pad
  Returns   : 1 if it succeeds
  Argument  : A pad ID and the message you want to send
- See       : http://etherpad.org/doc/v1.5.6/#index_sendclientsmessage_padid_msg
+ See       : http://etherpad.org/doc/v1.6.0/#index_sendclientsmessage_padid_msg
 
 =head2 check_token
 
@@ -1974,18 +2012,18 @@ See L<http://etherpad.org/doc/v1.5.6/#index_pad>
  Purpose   : Returns ok when the current api token is valid
  Returns   : 1 if the token is valid, 0 otherwise
  Argument  : None
- See       : http://etherpad.org/doc/v1.5.6/#index_checktoken
+ See       : http://etherpad.org/doc/v1.6.0/#index_checktoken
 
 =head2 Pads
 
-See L<http://etherpad.org/doc/v1.5.6/#index_pads>
+See L<http://etherpad.org/doc/v1.6.0/#index_pads>
 
 =head3 list_all_pads
 
  Usage     : $ec->list_all_pads()
  Purpose   : Lists all pads on this epl instance
  Returns   : An array or an array reference depending on the context, containing the pads names
- See       : http://etherpad.org/doc/v1.5.6/#index_listallpads
+ See       : http://etherpad.org/doc/v1.6.0/#index_listallpads
 
 =head1 INSTALL
 
@@ -2006,12 +2044,12 @@ You can find documentation for this module with the perldoc command.
 
 Bugs and feature requests will be tracked on:
 
-    https://git.framasoft.org/luc/etherpad/issues
+    https://framagit.org/luc/etherpad/issues
 
 The latest source code can be browsed and fetched at:
 
-    https://git.framasoft.org/luc/etherpad
-    git clone https://git.framasoft.org/luc/etherpad.git
+    https://framagit.org/luc/etherpad
+    git clone https://framagit.org/luc/etherpad.git
 
 Source code mirror:
 
